package com.nisum.employeeservice.controller;

import com.nisum.employeeservice.exception.ResourceNotFoundException;
import com.nisum.employeeservice.model.Employee;
import com.nisum.employeeservice.repository.EmployeeRepository;
import com.nisum.employeeservice.service.EmployeeService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.http.ResponseEntity;
import org.springframework.web.bind.annotation.*;

import java.util.List;

@CrossOrigin(origins = "*")
@RestController
@RequestMapping("/api/v1")
public class EmployeeController {

  @Autowired EmployeeService employeeService;
  @Autowired EmployeeRepository employeeRepository;

  @GetMapping("/employees")
  public List<Employee> getAllEmployees() {
    return employeeService.findAllEmployees();
  }

  @PostMapping("/employees")
  public Employee createEmployee(@RequestBody Employee employee) {
    return employeeService.addEmployee(employee);
  }

  @GetMapping("/employees/{id}")
  public ResponseEntity<Employee> getEmployeeById(@PathVariable(value = "id") Long employeeId) throws ResourceNotFoundException {
    Employee employee = employeeService.getEmployeeById(employeeId)
        .orElseThrow(() -> new ResourceNotFoundException("Employee by Id Not Found" + employeeId));
    return ResponseEntity.ok().body(employee);
  }

  @PutMapping("/employees/{id}")
  public ResponseEntity<Employee> updateEmployee(@PathVariable(value = "id") Long id, @RequestBody Employee employeedata) throws ResourceNotFoundException {
    Employee employee = employeeService.getEmployeeById(id).orElseThrow(() -> new ResourceNotFoundException("Employee Id updated :" +id));
    employee.setFirstName(employeedata.getFirstName());
    employee.setLastName(employeedata.getLastName());
    Employee employeeUpdated = employeeRepository.save(employee);
    return ResponseEntity.ok().body(employeeUpdated);

  }

  @DeleteMapping("/employees/{id}")
  public boolean deleteEmployee(@PathVariable Long employeeid) {
    employeeService.deleteEmployee(employeeid);
    return  true;
  }

}
